
/**
 * YAML trigger file.
 */
export interface LambdaTriggerConfig {

  /** EC2 config */
  ec2: EC2TriggerConfig;

  /** nshmp config */
  nshmp: NshmpTriggerConfig;
}

/**
 * nshmp-haz config.
 */
export interface NshmpTriggerConfig {

  /** Email to get notification */
  email: string;

  /** Optional: URL to config file. */
  nshmpConfigFile?: string;

  /**
   * Model to run:
   * - CEUS-2018
   * - CEUS-2014
   * - CEUS-2008
   * - COUS-2018
   * - COUS-2014
   * - COUS-2008
   * - WUS-2018
   * - WUS-2014
   * - WUS-2008
   * - AK-2007
   * - URL to download model if 'useCustomModel' is true
   */
  nshmpModel: string;

  /** URL to site file */
  nshmpSiteFile: string;

  /**
   * nshmp-haz program to run:
   * - deagg
   * - deagg-epsilon
   * - deagg-iml
   * - hazard
   * - hazard-2018
   * - rate
   */
  program: string;

  /** Return period for deagg */
  returnPeriod?: number

  /** Intensity measure level for deagg-epsilon */
  iml?: number;

  /** Whether to send updates when running nshmp-haz */
  sendUpdates: boolean;

  /** Cron format to send notification */
  sendUpdatesEvery: number;

  /** S3 bucket for output */
  s3Bucket: string;

  /** S3 output path */
  s3OutputPath?: string;

  /** S3 bucket direcotry name for outputs */
  s3OutputDirectory: string;

  /** Hazard map slices */
  slices?: number[];

  /** Whether to use a custom model */
  useCustomModel?: boolean;
}

/**
 * EC2 config.
 */
export interface EC2TriggerConfig {

  /** EC2 instance type */
  instanceType: string;

  /** Java memory allocation size */
  javaXmx: string;

  /** Whether to gain access to Java VisualVM */
  accessVisualVM?: boolean;
}
