import * as AWS from 'aws-sdk';
import { S3Event, Context } from 'aws-lambda';

import { NshmpHazS3Lambda } from './lambda/nshmp-haz-s3-lambda';
import { NshmpHazLambdaConfig } from './config/nshmp-haz-lambda-config';
import { NshmpLambdaUtil, LambdaError } from './lambda/nshmp-lambda-util';
import { LambdaConfig } from './config/lambda-config';

/* Lock to us-west-2 */
AWS.config.region = 'us-west-2';

/* Lock the known API versions to avoid future problems */
AWS.config.apiVersions = {
  ec2: '2016-11-15',
  s3: '2016-03-01'
};

/**
 * Lambda handler
 */
export const handler = async (event: S3Event, context: Context) => {
  console.log('\nLambda event:', JSON.stringify(event, null, 2));
  console.log('\nLambda context:', JSON.stringify(context, null, 2));

  /* Shorten id */
  const jobId = context.awsRequestId.split('-')[0];

  const lambda = new NshmpHazS3Lambda();
  const nshmpLambdaConfig = new NshmpHazLambdaConfig(jobId);

  return await nshmpLambdaConfig.getConfig(event.Records[0])
      .then((config: LambdaConfig) => {
        return lambda.startComputeJob(config);
      })
      .then(() => 'Running nshmp-haz')
      .catch(async (error: LambdaError) => {
        return await NshmpLambdaUtil.onError(error)
            .then(() => `Error [${error.message}]`)
            .catch(() => console.error(error));
      });
};
